@@ -3,7 +3,7 @@
  * The University of Illinois/NCSA
  * Open Source License (NCSA)
  *
- * Copyright (c) 2017-2023, Advanced Micro Devices, Inc.
+ * Copyright (c) 2017-2025, Advanced Micro Devices, Inc.
  * All rights reserved.
  *
  * Developed by:
@@ -52,12 +52,16 @@
 #include <vector>
 #include <unordered_set>
 #include <map>
+#include <type_traits>
+#include <optional>
 
 #include "rocm_smi/rocm_smi_monitor.h"
 #include "rocm_smi/rocm_smi_power_mon.h"
 #include "rocm_smi/rocm_smi_common.h"
 #include "rocm_smi/rocm_smi.h"
 #include "rocm_smi/rocm_smi_counters.h"
+#include "rocm_smi/rocm_smi_properties.h"
+#include "rocm_smi/rocm_smi_gpu_metrics.h"
 #include "shared_mutex.h"   //NOLINT
 
 namespace amd {
@@ -100,6 +104,8 @@ enum DevInfoTypes {
   kDevOverDriveLevel,
   kDevMemOverDriveLevel,
   kDevDevID,
+  kDevXGMIPhysicalID,
+  kDevDevRevID,
   kDevDevProdName,
   kDevDevProdNum,
   kDevVendorID,
@@ -143,6 +149,8 @@ enum DevInfoTypes {
   kDevFwVersionMe,
   kDevFwVersionMec,
   kDevFwVersionMec2,
+  kDevFwVersionMes,
+  kDevFwVersionMesKiq,
   kDevFwVersionPfp,
   kDevFwVersionRlc,
   kDevFwVersionRlcSrlc,
@@ -164,7 +172,8 @@ enum DevInfoTypes {
   kDevGpuReset,
   kDevAvailableComputePartition,
   kDevComputePartition,
-  kDevMemoryPartition
+  kDevMemoryPartition,
+  kDevAvailableMemoryPartition,
 };
 
 typedef struct {
@@ -172,6 +181,7 @@ typedef struct {
     std::vector<DevInfoTypes> variants;
 } dev_depends_t;
 
+
 class Device {
  public:
     explicit Device(std::string path, RocmSMI_env_vars const *e);
@@ -212,14 +222,34 @@ class Device {
     void set_evt_notif_anon_fd(uint32_t fd) {
                                    evt_notif_anon_fd_ = static_cast<int>(fd);}
     int evt_notif_anon_fd(void) const {return evt_notif_anon_fd_;}
-    metrics_table_header_t & gpu_metrics_ver(void) {return gpu_metrics_ver_;}
+
     void fillSupportedFuncs(void);
     void DumpSupportedFunctions(void);
     bool DeviceAPISupported(std::string name, uint64_t variant,
                                                         uint64_t sub_variant);
     rsmi_status_t restartAMDGpuDriver(void);
+    rsmi_status_t isRestartInProgress(bool *isRestartInProgress,
+                                      bool *isAMDGPUModuleLive);
     rsmi_status_t storeDevicePartitions(uint32_t dv_ind);
     template <typename T> std::string readBootPartitionState(uint32_t dv_ind);
+    rsmi_status_t check_amdgpu_property_reinforcement_query(uint32_t dev_idx, AMDGpuVerbTypes_t verb_type);
+
+    void dev_set_gpu_metric(GpuMetricsBasePtr gpu_metrics_ptr) { m_gpu_metrics_ptr = std::move(gpu_metrics_ptr); };
+    GpuMetricsBasePtr& dev_get_gpu_metric() { return m_gpu_metrics_ptr; };
+    const AMDGpuMetricsHeader_v1_t& dev_get_metrics_header() {return m_gpu_metrics_header; }
+    rsmi_status_t setup_gpu_metrics_reading();
+    rsmi_status_t dev_read_gpu_metrics_header_data();
+    rsmi_status_t dev_read_gpu_metrics_all_data();
+    rsmi_status_t run_internal_gpu_metrics_query(AMDGpuMetricsUnitType_t metric_counter, AMDGpuDynamicMetricTblValues_t& values);
+    rsmi_status_t dev_log_gpu_metrics(std::ostringstream& outstream_metrics);
+    AMGpuMetricsPublicLatestTupl_t dev_copy_internal_to_external_metrics();
+
+    static const std::map<DevInfoTypes, const char*> devInfoTypesStrings;
+    void set_smi_device_id(uint32_t i) { m_device_id = i; }
+    void set_smi_partition_id(uint32_t i) { m_partition_id = i; }
+    static const char* get_type_string(DevInfoTypes type);
+    rsmi_status_t get_smi_device_identifiers(uint32_t device_id,
+                  rsmi_device_identifiers_t *device_identifiers);
 
  private:
     std::shared_ptr<Monitor> monitor_;
@@ -239,7 +269,10 @@ class Device {
                                             std::vector<std::string> *retVec);
     int readDevInfoBinary(DevInfoTypes type, std::size_t b_size,
                                             void *p_binary_data);
-    int writeDevInfoStr(DevInfoTypes type, std::string valStr);
+    int writeDevInfoStr(DevInfoTypes type, std::string valStr,
+                        bool returnWriteErr = false);
+    rsmi_status_t run_amdgpu_property_reinforcement_query(const AMDGpuPropertyQuery_t& amdgpu_property_query);
+
     uint64_t bdfid_;
     uint64_t kfd_gpu_id_;
     std::unordered_set<rsmi_event_group_t,
@@ -249,9 +282,15 @@ class Device {
 
     int evt_notif_anon_fd_;
     FILE *evt_notif_anon_file_ptr_;
-    struct metrics_table_header_t gpu_metrics_ver_;
+
+    GpuMetricsBasePtr m_gpu_metrics_ptr;
+    AMDGpuMetricsHeader_v1_t m_gpu_metrics_header;
+    uint64_t m_gpu_metrics_updated_timestamp;
+    uint32_t m_device_id;
+    uint32_t m_partition_id;
 };
 
+
 }  // namespace smi
 }  // namespace amd
 
