@@ -3,7 +3,7 @@
  * The University of Illinois/NCSA
  * Open Source License (NCSA)
  *
- * Copyright (c) 2017, Advanced Micro Devices, Inc.
+ * Copyright (c) 2017-2025, Advanced Micro Devices, Inc.
  * All rights reserved.
  *
  * Developed by:
@@ -41,26 +41,23 @@
  *
  */
 
-#include <assert.h>
 #include <dirent.h>
 
-#include <fstream>
-#include <string>
-#include <cstdint>
-#include <map>
-#include <iostream>
 #include <algorithm>
+#include <cassert>
+#include <cstdint>
+#include <fstream>
+#include <iostream>
+#include <map>
 #include <regex>  // NOLINT
+#include <string>
 #include <vector>
 
-#include "rocm_smi/rocm_smi_main.h"
 #include "rocm_smi/rocm_smi_monitor.h"
 #include "rocm_smi/rocm_smi_utils.h"
 #include "rocm_smi/rocm_smi_exception.h"
 #include "rocm_smi/rocm_smi_logger.h"
 
-using namespace ROCmLogging;
-
 namespace amd {
 namespace smi {
 
@@ -81,6 +78,8 @@ static const char *kMonPowerCapName = "power#_cap";
 static const char *kMonPowerCapMaxName = "power#_cap_max";
 static const char *kMonPowerCapMinName = "power#_cap_min";
 static const char *kMonPowerAveName = "power#_average";
+static const char *kMonPowerInputName = "power#_input";
+static const char *kMonPowerLabelName = "power#_label";
 static const char *kMonTempMaxName = "temp#_max";
 static const char *kMonTempMinName = "temp#_min";
 static const char *kMonTempMaxHystName = "temp#_max_hyst";
@@ -110,7 +109,7 @@ static const char *kTempSensorTypeJunctionName = "junction";
 static const char *kTempSensorTypeEdgeName = "edge";
 
 static const char *kTempSensorTypeVddgfxName = "vddgfx";
-
+static const char *kTempSensorTypeVddboardName = "vddboard";
 
 static const std::map<std::string, rsmi_temperature_type_t>
                                                         kTempSensorNameMap = {
@@ -122,6 +121,7 @@ static const std::map<std::string, rsmi_temperature_type_t>
 static const std::map<std::string, rsmi_voltage_type_t>
                                                         kVoltSensorNameMap = {
     {kTempSensorTypeVddgfxName, RSMI_VOLT_TYPE_VDDGFX},
+    {kTempSensorTypeVddboardName, RSMI_VOLT_TYPE_VDDBOARD},
 };
 
 static const std::map<MonitorTypes, const char *> kMonitorNameMap = {
@@ -136,6 +136,8 @@ static const std::map<MonitorTypes, const char *> kMonitorNameMap = {
     {kMonPowerCapMax, kMonPowerCapMaxName},
     {kMonPowerCapMin, kMonPowerCapMinName},
     {kMonPowerAve, kMonPowerAveName},
+    {kMonPowerInput, kMonPowerInputName},
+    {kMonPowerLabel, kMonPowerLabelName},
     {kMonTempMax, kMonTempMaxName},
     {kMonTempMin, kMonTempMinName},
     {kMonTempMaxHyst, kMonTempMaxHystName},
@@ -203,7 +205,8 @@ static const std::map<const char *, monitor_depends_t> kMonFuncDependsMap = {
                                       .variants = {kMonInvalid},
                                     }
   },
-  {"rsmi_dev_power_cap_default_get",        { .mandatory_depends = {kMonPowerCapDefaultName},
+  {"rsmi_dev_power_cap_default_get", { .mandatory_depends =
+                                      {kMonPowerCapDefaultName},
                                       .variants = {kMonInvalid},
                                     }
   },
@@ -286,8 +289,7 @@ static const std::map<const char *, monitor_depends_t> kMonFuncDependsMap = {
     env_ = nullptr;
 #endif
 }
-Monitor::~Monitor(void) {
-}
+Monitor::~Monitor(void) = default;
 
 std::string
 Monitor::MakeMonitorPath(MonitorTypes type, uint32_t sensor_id) {
@@ -313,6 +315,7 @@ int Monitor::writeMonitor(MonitorTypes type, uint32_t sensor_id,
 // This string version should work for all valid monitor types
 int Monitor::readMonitor(MonitorTypes type, uint32_t sensor_id,
                                                            std::string *val) {
+  std::ostringstream ss;
   assert(val != nullptr);
 
   std::string temp_str;
@@ -320,15 +323,25 @@ int Monitor::readMonitor(MonitorTypes type, uint32_t sensor_id,
 
   DBG_FILE_ERROR(sysfs_path, (std::string *)nullptr)
   int ret = ReadSysfsStr(sysfs_path, val);
+  ss << __PRETTY_FUNCTION__
+     << " | Success | Read hwmon file: " << sysfs_path
+     << " | Type: " << monitorTypesToString.at(type)
+     << " | Sensor id: " << std::to_string(sensor_id)
+     << " | Data: " << *val
+     << " | Returning: " << std::to_string(ret) << " |";
+  LOG_INFO(ss);
   return ret;
 }
 
 int32_t
 Monitor::setTempSensorLabelMap(void) {
+  std::ostringstream ss;
+  ss << __PRETTY_FUNCTION__ << " | ======= start =======";
+  LOG_TRACE(ss);
   std::string type_str;
   int ret;
 
-  if (temp_type_index_map_.size() > 0) {
+  if (!temp_type_index_map_.empty()) {
     return 0;  // We've already filled in the map
   }
   auto add_temp_sensor_entry = [&](uint32_t file_index) {
@@ -366,7 +379,7 @@ Monitor::setVoltSensorLabelMap(void) {
   std::string type_str;
   int ret;
 
-  if (volt_type_index_map_.size() > 0) {
+  if (!volt_type_index_map_.empty()) {
     return 0;  // We've already filled in the map
   }
   auto add_volt_sensor_entry = [&](uint32_t file_index) {
@@ -387,7 +400,13 @@ Monitor::setVoltSensorLabelMap(void) {
   };
 
   for (uint32_t i = 0; i < RSMI_VOLT_TYPE_LAST + 1; ++i) {
-    ret = add_volt_sensor_entry(i);
+    // VDDGFX -> 0, VDDNB -> 1, VDDBOARD -> 2
+    // Here the VDDNB will be skipped as it is not defined in the enum and not supported by AMD.
+    auto file_index = i;
+    if (i >= RSMI_VOLT_TYPE_VDDBOARD) {
+      file_index = i + 1;
+    }
+    ret = add_volt_sensor_entry(file_index);
     if (ret) {
       return ret;
     }
@@ -499,10 +518,10 @@ typedef enum {
 static monitor_types getFuncType(std::string f_name) {
   monitor_types ret = eDefaultMonitor;
 
-  if (f_name.compare("rsmi_dev_temp_metric_get") == 0) {
+  if (f_name == "rsmi_dev_temp_metric_get") {
     ret = eTempMonitor;
   }
-  if (f_name.compare("rsmi_dev_volt_metric_get") == 0) {
+  if (f_name == "rsmi_dev_volt_metric_get") {
     ret = eVoltMonitor;
   }
   return ret;
@@ -603,22 +622,22 @@ void Monitor::fillSupportedFuncs(SupportedFuncMap *supported_funcs) {
       } else {
         supported_monitors = intersect;
       }
-      if (supported_monitors.size() > 0) {
-        for (uint32_t i = 0; i < supported_monitors.size(); ++i) {
+      if (!supported_monitors.empty()) {
+        for (uint64_t &supported_monitor : supported_monitors) {
           if (m_type == eDefaultMonitor) {
-            assert(supported_monitors[i] > 0);
-            supported_monitors[i] |=
-                    (supported_monitors[i] - 1) << MONITOR_TYPE_BIT_POSITION;
+            assert(supported_monitor > 0);
+            supported_monitor |=
+                    (supported_monitor - 1) << MONITOR_TYPE_BIT_POSITION;
           } else if (m_type == eTempMonitor) {
             // Temp sensor file names are 1-based
-            assert(supported_monitors[i] > 0);
-            supported_monitors[i] |=
-                 static_cast<uint64_t>(getTempSensorEnum(supported_monitors[i]))
+            assert(supported_monitor > 0);
+            supported_monitor |=
+                 static_cast<uint64_t>(getTempSensorEnum(supported_monitor))
                                                 << MONITOR_TYPE_BIT_POSITION;
           } else if (m_type == eVoltMonitor) {
             // Voltage sensor file names are 0-based
-            supported_monitors[i] |=
-                 static_cast<uint64_t>(getVoltSensorEnum(supported_monitors[i]))
+            supported_monitor |=
+                 static_cast<uint64_t>(getVoltSensorEnum(supported_monitor))
                                                 << MONITOR_TYPE_BIT_POSITION;
           } else {
             assert(false);  // Unexpected monitor type
@@ -629,10 +648,10 @@ void Monitor::fillSupportedFuncs(SupportedFuncMap *supported_funcs) {
       }
     }
 
-    if (it->second.variants.size() == 0) {
+    if (it->second.variants.empty()) {
       (*supported_funcs)[it->first] = nullptr;
       supported_variants = nullptr;  // Invoke destructor
-    } else if ((*supported_variants).size() > 0) {
+    } else if (!(*supported_variants).empty()) {
       (*supported_funcs)[it->first] = supported_variants;
     }
 
